[![pypi](https://img.shields.io/pypi/dt/discord-holo-api?style=for-the-badge)](https://pypi.org/project/discord-holo-api)
[![pypi](https://img.shields.io/pypi/v/discord-holo-api?style=for-the-badge)](https://pypi.org/project/discord-holo-api)

# discord-holo-api

## Requirements
- Python 3.6 and up - https://www.python.org/downloads/

# Install
```
pip i discord-holo-api
```

or

```
pip install discord-holo-api

```
# How to use

```py
import DiscordHoloApi
print(DiscordHoloApi.random("art"))


/*Available endpoint

["404, anal, art, ask, avatar, baka, bite, bj, blowjob, boobs, cry, cuddle, cum, dance, ego, ero, erofeet, erok, erokemo, eroyuri, feed, feet, feetg, fox_girl, futanari, glare, hentai_gif, highfive, holo, holoero, hololewd, hug, kemonomimi, kiss, kuni, les, lewd, lick, loli, meow, neko, ngif, nom, pat, poke, pressf, punch, pussy, pwankg, sex, slap, slappope, smug, solo, tickle, tits, trap, waifu, wallpaper, wasted, wink, woof, yuri"]
    
    */
```
    
## Links

*   [Website](http://discord-holo-api.ml/api/)
*   [Api status](http://discord-holo-api.ml/api/stats)
*   [GitHub](https://github.com/gimartmart/discord_holo_api_py)
*   [Discord](https://discord.gg/TApdfmN)